@@ -1,20 +1,20 @@
 package Acme::phillup;
 
-use 5.006
+use 5.006;
 use strict;
 use warnings;
 
 =head1 NAME
 
-Acme::phillup - The great new Acme::phillup!
+Acme::phillup - Test module for YAPC::NA 2012
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -28,11 +28,17 @@ if you don't export anything, such as for a purely object-oriented module.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 function1
+=head2 sum
+
+  sum-thing
 
 =cut
 
-sub function1 {
+sub sum {
+  my $sum = 0;
+  foreach my $num (@_){
+    $sum += $num;
+  }
 }
 
 =head2 function2
